# yssh
A command line SSH helper tool combined ssh, expect and multi-threading.

To install :  pip install yssh

Usage      :  python3 -mypip 

It's a screwdriver, not a set of tools you have to learn about. 

what it can do :

0. reduce interactive requirement by providing answers and passwords
1. run command remotely in specified parallel level
2. ship and run script(or a dir including the target script) remotely in specified parallel level
4. interactive (no parallel) in case you still need to log onto each of them


check [examples](https://github.com/laowangv5/yssh/blob/master/examples/usage.txt) for basic usage info.


